@@ -4,7 +4,7 @@
 """
 
 from typing import List, Optional, Dict, Any
-from filekits.base_io.down_load import batch_download_encode_base64
+from filekits.base_io import download_encode_base64, batch_download_encode_base64
 
 
 def prepare_messages(
@@ -50,8 +50,8 @@ def rebuild_messages_single_image(
     provider_name: str,
     system_prompt: str,
     user_text: str,
-    include_img: bool = False,
-    img_list: Optional[List[str]] = None,
+    reject_single_image: bool,
+    img_list: list,
 ) -> List[Dict[str, Any]]:
     """
     重新构造messages，只使用第一张图片
@@ -60,22 +60,25 @@ def rebuild_messages_single_image(
         provider_name: 提供商名称
         system_prompt: 系统提示词
         user_text: 用户文本
-        include_img: 是否包含图片
+        reject_single_image: 是否禁止单张图片（为True时若图片数量为1则抛异常）
         img_list: 图片URL列表
 
     Returns:
         格式化后的消息列表（只包含第一张图片）
     """
-    if img_list is None:
-        img_list = []
+    if not img_list:
+        raise ValueError("图片 img_list 不能为空!")
 
-    if len(img_list) == 1 and include_img:
-        print("异常：图片数量 未超出限制")
-        print(f"img_list : {img_list}")
-        raise Exception("异常：图片数量 == 1，未超出限制")
+    img_num = len(img_list)
+
+    if reject_single_image:
+        if img_num == 1:
+            error_message = "异常：图片数量 == 1，未超出限制"
+            print(f"{error_message}，img_list : {img_list}")
+            raise Exception(error_message)
 
     # 重新构造messages，只使用第一张图片
-    return prepare_messages(provider_name, system_prompt, user_text, include_img, [img_list[0]] if img_list else [])
+    return prepare_messages(provider_name, system_prompt, user_text, True, [img_list[0]] if img_list else [])
 
 
 def _build_content_by_provider(
@@ -96,6 +99,13 @@ def _build_content_by_provider(
         user_content = user_text
         img_list = batch_download_encode_base64(img_list)
 
+    elif provider_name == "openrouter":
+        # openrouter 需要base64格式的图片
+        img_list = convert_images_to_base64(img_list)
+        user_content = [{"type": "image_url", "image_url": {"url": img}} for img in img_list]
+        user_content.append({"type": "text", "text": user_text})
+        system_content = [{"type": "text", "text": system_prompt}]
+
     else:
         # 兼容通用的 "openai", "zhipu", "modelscope" 格式
         user_content = [{"type": "image_url", "image_url": {"url": img}} for img in img_list]
@@ -105,6 +115,47 @@ def _build_content_by_provider(
     return system_content, user_content
 
 
+def convert_images_to_base64(img_list: List[str]) -> List[str]:
+    """
+    将图片URL列表转换为base64格式
+
+    Args:
+        img_list: 图片URL列表
+
+    Returns:
+        转换后的图片URL列表（base64格式的保留，非图片格式的保持原样）
+    """
+    if not img_list:
+        raise ValueError("图片 img_list 不能为空!")
+
+    processed_img_list = []
+    valid_extensions = ('.jpg', '.jpeg', '.png')
+
+    for img_url in img_list:
+        # 检查是否为有效的图片URL
+        img_lower = img_url.lower()
+        if img_lower.endswith(valid_extensions):
+            try:
+                # 下载并转换为base64
+                base64_str = download_encode_base64(img_url)
+                if base64_str:
+                    # 构建base64格式的图片URL
+                    mime_type = 'image/jpeg' if img_lower.endswith(('.jpg', '.jpeg')) else 'image/png'
+                    base64_url = f"data:{mime_type};base64,{base64_str}"
+                    processed_img_list.append(base64_url)
+                    print(f"已将图片转换为base64格式: {img_url}")
+                else:
+                    print(f"图片 {img_url} 转换为base64失败，保持原始URL")
+                    processed_img_list.append(img_url)
+            except Exception as e:
+                print(f"转换图片为base64失败 {img_url}: {e}")
+                processed_img_list.append(img_url)
+        else:
+            processed_img_list.append(img_url)
+
+    return processed_img_list
+
+
 def _build_message_structure(
     provider_name: str, system_content: Any, user_content: Any, img_list: List[str]
 ) -> List[Dict[str, Any]]:
